@@ -38,6 +38,8 @@ __all__ = (
     "DescribePendingMaintenanceActionsPaginatorName",
     "SourceTypeType",
     "ServiceName",
+    "PaginatorName",
+    "WaiterName",
 )
 
 
@@ -346,3 +348,19 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "describe_certificates",
+    "describe_db_cluster_parameter_groups",
+    "describe_db_cluster_parameters",
+    "describe_db_cluster_snapshots",
+    "describe_db_clusters",
+    "describe_db_engine_versions",
+    "describe_db_instances",
+    "describe_db_subnet_groups",
+    "describe_event_subscriptions",
+    "describe_events",
+    "describe_global_clusters",
+    "describe_orderable_db_instance_options",
+    "describe_pending_maintenance_actions",
+]
+WaiterName = Literal["db_instance_available", "db_instance_deleted"]
